==> react-ui-library-6.0.0.tgz: package/src/stories/button-story.js <==
import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  CogIcon,
  Pane,
  Button,
  Display4,
  theme
} from '../components'
import Content from './Content'
const { majorScale } = theme

export default function buttonStory (module) {
  storiesOf('Button', module)
    .add('usage', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Button

The Button component. Implements \`<Box />\`.

* Set \`paddingX='0'\` if you are using icons

\`\`\`
<Display4 display='inline-block' marginRight={majorScale(1)} marginBottom={majorScale(1)}>Large</Display4>
<Pane marginBottom={majorScale(2)}>
  <Button paddingX='0' marginRight={majorScale(1)}><CogIcon /></Button>
  <Button marginRight={majorScale(1)}>Default Button</Button>
  <Button primary marginRight={majorScale(1)}>Primary Button</Button>
  <Button danger marginRight={majorScale(1)}>Danger Button</Button>
</Pane>

<Display4 display='inline-block' marginRight={majorScale(1)} marginBottom={majorScale(1)}>Default</Display4>
<Pane>
  <Button size='default' paddingX='0' marginRight={majorScale(1)}><CogIcon size='mini' /></Button>
  <Button size='default' marginRight={majorScale(1)}>Default Button</Button>
  <Button size='default' primary marginRight={majorScale(1)}>Primary Button</Button>
  <Button size='default' danger marginRight={majorScale(1)}>Danger Button</Button>
</Pane>
\`\`\`
`}
          </Content>
          <Display4 display='inline-block' marginRight={majorScale(1)} marginBottom={majorScale(1)}>Large</Display4>
          <Pane marginBottom={majorScale(2)}>
            <Button paddingX='0' marginRight={majorScale(1)}><CogIcon /></Button>
            <Button marginRight={majorScale(1)}>Default Button</Button>
            <Button primary marginRight={majorScale(1)}>Primary Button</Button>
            <Button danger marginRight={majorScale(1)}>Danger Button</Button>
          </Pane>

          <Display4 display='inline-block' marginRight={majorScale(1)} marginBottom={majorScale(1)}>Default</Display4>
          <Pane>
            <Button size='default' paddingX='0' marginRight={majorScale(1)}><CogIcon size='mini' /></Button>
            <Button size='default' marginRight={majorScale(1)}>Default Button</Button>
            <Button size='default' primary marginRight={majorScale(1)}>Primary Button</Button>
            <Button size='default' danger marginRight={majorScale(1)}>Danger Button</Button>
          </Pane>
          <Content markdown>
            {`
prop | version | type | default | description
-----|---------|------| --------|----------
\`size\`| v3.0.0 | \`large\`, \`default\` | \`large\` | as defined by \`theme.controlSizes\`
\`secondary\`| v1 | boolean | \`true\` | renders a secondary button, used by default
\`primary\`| v1 | boolean | \`undefined\` | renders a green primary button
\`danger\`| v1 | boolean | \`undefined\` | renders a pinkish button

`}
          </Content>
        </Pane>
      </App>
    ))
}

==> react-ui-library-7.0.0.tgz: package/src/stories/button-story.js <==
import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  CogIcon,
  Pane,
  Button,
  Display4,
  theme
} from '../components'
import Content from './Content'
const { majorScale } = theme

export default function buttonStory (module) {
  storiesOf('Button', module)
    .add('usage', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Button

The Button component. Implements \`<Box />\`.

* Set \`paddingX='0'\` if you are using icons

\`\`\`
<Display4 display='inline-block' marginRight={majorScale(1)} marginBottom={majorScale(1)}>Default</Display4>
<Pane marginBottom={majorScale(2)}>
  <Button paddingX='0' marginRight={majorScale(1)}><CogIcon /></Button>
  <Button marginRight={majorScale(1)}>Default Button</Button>
  <Button primary marginRight={majorScale(1)}>Primary Button</Button>
  <Button danger marginRight={majorScale(1)}>Danger Button</Button>
</Pane>

<Display4 display='inline-block' marginRight={majorScale(1)} marginBottom={majorScale(1)}>Small</Display4>
<Pane>
  <Button size='default' paddingX='0' marginRight={majorScale(1)}><CogIcon size='mini' /></Button>
  <Button size='default' marginRight={majorScale(1)}>Default Button</Button>
  <Button size='default' primary marginRight={majorScale(1)}>Primary Button</Button>
  <Button size='default' danger marginRight={majorScale(1)}>Danger Button</Button>
</Pane>
\`\`\`
`}
          </Content>
          <Display4 display='inline-block' marginRight={majorScale(1)} marginBottom={majorScale(1)}>Default</Display4>
          <Pane marginBottom={majorScale(2)}>
            <Button paddingX='0' marginRight={majorScale(1)}><CogIcon /></Button>
            <Button marginRight={majorScale(1)}>Default Button</Button>
            <Button primary marginRight={majorScale(1)}>Primary Button</Button>
            <Button danger marginRight={majorScale(1)}>Danger Button</Button>
          </Pane>

          <Display4 display='inline-block' marginRight={majorScale(1)} marginBottom={majorScale(1)}>Small</Display4>
          <Pane>
            <Button size='default' paddingX='0' marginRight={majorScale(1)}><CogIcon size='mini' /></Button>
            <Button size='default' marginRight={majorScale(1)}>Default Button</Button>
            <Button size='default' primary marginRight={majorScale(1)}>Primary Button</Button>
            <Button size='default' danger marginRight={majorScale(1)}>Danger Button</Button>
          </Pane>
          <Content markdown>
            {`
prop | version | type | default | description
-----|---------|------| --------|----------
\`size\`| v3.0.0 | \`small\`, \`default\` | \`default\` | as defined by \`theme.controlSizes\`
\`secondary\`| v1 | boolean | \`true\` | renders a secondary button, used by default
\`primary\`| v1 | boolean | \`undefined\` | renders a green primary button
\`danger\`| v1 | boolean | \`undefined\` | renders a pinkish button

`}
          </Content>
        </Pane>
      </App>
    ))
}
